@@ -11,7 +11,6 @@ from copy import deepcopy
 
 from tiddlyweb.specialbag import get_bag_retriever, SpecialBagError
 from tiddlyweb.model.policy import Policy
-from tiddlyweb.model.tiddler import Tiddler
 from tiddlyweb.util import superclass_name
 
 
@@ -85,13 +84,13 @@ EMPTY_HOOKS = {
         'put': [],
         'delete': [],
         'get': [],
-        }
+}
 HOOKS = {
         'recipe': deepcopy(EMPTY_HOOKS),
         'bag': deepcopy(EMPTY_HOOKS),
         'tiddler': deepcopy(EMPTY_HOOKS),
         'user': deepcopy(EMPTY_HOOKS),
-        }
+}
 
 
 class Store(object):
@@ -102,7 +101,7 @@ class Store(object):
     """
 
     def __init__(self, engine, config=None, environ=None):
-        if config == None:
+        if config is None:
             config = {}
         self.engine = engine
         self.environ = environ
@@ -147,7 +146,7 @@ class Store(object):
                     thing = retriever[1](thing)
                 except SpecialBagError, exc:
                     raise NoTiddlerError(
-                            'unable to get remote tiddler: %s:%s:%s'
+                            'unable to get special tiddler: %s:%s:%s'
                             % (thing.bag, thing.title, exc))
                 thing.store = self
                 self._do_hook('get', thing)
@@ -207,7 +206,7 @@ class Store(object):
             try:
                 return retriever[0](bag.name)
             except SpecialBagError, exc:
-                raise NoBagError('unable to get remote bag: %s: %s'
+                raise NoBagError('unable to get special bag: %s: %s'
                         % (bag.name, exc))
         list_func = getattr(self.storage, 'list_bag_tiddlers')
         return list_func(bag)
